==> qtjambi-qt3dcore-5.15.14-sources.jar: io/qt/qt3d/core/QNodeCommand.java <==
package io.qt.qt3d.core;

import io.qt.*;


/**
 * <p>The base class for all CommandRequested QSceneChange events</p>
 * <p>Java wrapper for Qt's class <a href="http://doc.qt.io/qt-5/qt3dcore-qnodecommand.html">Qt3DCore::QNodeCommand</a></p>
 */
public class QNodeCommand extends io.qt.qt3d.core.QSceneChange
{
    
    /**
     * <p>See <a href="http://doc.qt.io/qt-5/qt3dcore-qnodecommand.html#QNodeCommand">Qt3DCore::QNodeCommand::QNodeCommand(Qt3DCore::QNodeId)</a></p>
     */
    @Deprecated
    public QNodeCommand(io.qt.qt3d.core.@NonNull QNodeId id){
        super((QPrivateConstructor)null);
        initialize_native(this, id);
    }
    
    @Deprecated
    private native static void initialize_native(QNodeCommand instance, io.qt.qt3d.core.QNodeId id);
    
    /**
     * <p>See <a href="http://doc.qt.io/qt-5/qt3dcore-qnodecommand.html#commandId">Qt3DCore::QNodeCommand::commandId()const</a></p>
     */
    @QtUninvokable
    public final long commandId(){
        return commandId_native_constfct(QtJambi_LibraryUtilities.internal.nativeId(this));
    }
    
    @QtUninvokable
    private native long commandId_native_constfct(long __this__nativeId);
    
    /**
     * <p>See <a href="http://doc.qt.io/qt-5/qt3dcore-qnodecommand.html#data">Qt3DCore::QNodeCommand::data()const</a></p>
     */
    @QtUninvokable
    public final java.lang.Object data(){
        return data_native_constfct(QtJambi_LibraryUtilities.internal.nativeId(this));
    }
    
    @QtUninvokable
    private native java.lang.Object data_native_constfct(long __this__nativeId);
    
    /**
     * <p>See <a href="http://doc.qt.io/qt-5/qt3dcore-qnodecommand.html#inReplyTo">Qt3DCore::QNodeCommand::inReplyTo()const</a></p>
     */
    @QtUninvokable
    public final long inReplyTo(){
        return inReplyTo_native_constfct(QtJambi_LibraryUtilities.internal.nativeId(this));
    }
    
    @QtUninvokable
    private native long inReplyTo_native_constfct(long __this__nativeId);
    
    /**
     * <p>See <a href="http://doc.qt.io/qt-5/qt3dcore-qnodecommand.html#name">Qt3DCore::QNodeCommand::name()const</a></p>
     */
    @QtUninvokable
    public final java.lang.@NonNull String name(){
        return name_native_constfct(QtJambi_LibraryUtilities.internal.nativeId(this));
    }
    
    @QtUninvokable
    private native java.lang.String name_native_constfct(long __this__nativeId);
    
    /**
     * <p>See <a href="http://doc.qt.io/qt-5/qt3dcore-qnodecommand.html#setData">Qt3DCore::QNodeCommand::setData(QVariant)</a></p>
     */
    @QtUninvokable
    public final void setData(java.lang.Object data){
        setData_native_cref_QVariant(QtJambi_LibraryUtilities.internal.nativeId(this), data);
    }
    
    @QtUninvokable
    private native void setData_native_cref_QVariant(long __this__nativeId, java.lang.Object data);
    
    /**
     * <p>See <a href="http://doc.qt.io/qt-5/qt3dcore-qnodecommand.html#setName">Qt3DCore::QNodeCommand::setName(QString)</a></p>
     */
    @QtUninvokable
    public final void setName(java.lang.@NonNull String name){
        setName_native_cref_QString(QtJambi_LibraryUtilities.internal.nativeId(this), name);
    }
    
    @QtUninvokable
    private native void setName_native_cref_QString(long __this__nativeId, java.lang.String name);
    
    /**
     * <p>See <a href="http://doc.qt.io/qt-5/qt3dcore-qnodecommand.html#setReplyToCommandId">Qt3DCore::QNodeCommand::setReplyToCommandId(Qt3DCore::QNodeCommand::CommandId)</a></p>
     */
    @QtUninvokable
    public final void setReplyToCommandId(long id){
        setReplyToCommandId_native_Qt3DCore_QNodeCommand_CommandId(QtJambi_LibraryUtilities.internal.nativeId(this), id);
    }
    
    @QtUninvokable
    private native void setReplyToCommandId_native_Qt3DCore_QNodeCommand_CommandId(long __this__nativeId, long id);
    
    /**
     * Constructor for internal use only.
     * @param p expected to be <code>null</code>.
     */
    @NativeAccess
    protected QNodeCommand(QPrivateConstructor p) { super(p); } 
    
}

==> qtjambi-qt3dcore-5.15.19-sources.jar: io/qt/qt3d/core/QNodeCommand.java <==
package io.qt.qt3d.core;

import io.qt.*;


/**
 * <p>The base class for all CommandRequested QSceneChange events</p>
 * <p>Java wrapper for Qt class <code><a href="http://doc.qt.io/qt-5/qt3dcore-qnodecommand.html">Qt3DCore::QNodeCommand</a></code></p>
 */
public class QNodeCommand extends io.qt.qt3d.core.QSceneChange
{
    
    /**
     * <p>See <code><a href="http://doc.qt.io/qt-5/qt3dcore-qnodecommand.html#QNodeCommand">Qt3DCore::QNodeCommand::<wbr/>QNodeCommand(Qt3DCore::QNodeId)</a></code></p>
     */
    public QNodeCommand(io.qt.qt3d.core.@NonNull QNodeId id){
        super((QPrivateConstructor)null);
        initialize_native(this, id);
    }
    
    private native static void initialize_native(QNodeCommand instance, io.qt.qt3d.core.QNodeId id);
    
    /**
     * <p>See <code><a href="http://doc.qt.io/qt-5/qt3dcore-qnodecommand.html#commandId">Qt3DCore::QNodeCommand::<wbr/>commandId()const</a></code></p>
     */
    @QtUninvokable
    public final long commandId(){
        return commandId_native_constfct(QtJambi_LibraryUtilities.internal.nativeId(this));
    }
    
    @QtUninvokable
    private native long commandId_native_constfct(long __this__nativeId);
    
    /**
     * <p>See <code><a href="http://doc.qt.io/qt-5/qt3dcore-qnodecommand.html#data">Qt3DCore::QNodeCommand::<wbr/>data()const</a></code></p>
     */
    @QtUninvokable
    public final java.lang.Object data(){
        return data_native_constfct(QtJambi_LibraryUtilities.internal.nativeId(this));
    }
    
    @QtUninvokable
    private native java.lang.Object data_native_constfct(long __this__nativeId);
    
    /**
     * <p>See <code><a href="http://doc.qt.io/qt-5/qt3dcore-qnodecommand.html#inReplyTo">Qt3DCore::QNodeCommand::<wbr/>inReplyTo()const</a></code></p>
     */
    @QtUninvokable
    public final long inReplyTo(){
        return inReplyTo_native_constfct(QtJambi_LibraryUtilities.internal.nativeId(this));
    }
    
    @QtUninvokable
    private native long inReplyTo_native_constfct(long __this__nativeId);
    
    /**
     * <p>See <code><a href="http://doc.qt.io/qt-5/qt3dcore-qnodecommand.html#name">Qt3DCore::QNodeCommand::<wbr/>name()const</a></code></p>
     */
    @QtUninvokable
    public final java.lang.@NonNull String name(){
        return name_native_constfct(QtJambi_LibraryUtilities.internal.nativeId(this));
    }
    
    @QtUninvokable
    private native java.lang.String name_native_constfct(long __this__nativeId);
    
    /**
     * <p>See <code><a href="http://doc.qt.io/qt-5/qt3dcore-qnodecommand.html#setData">Qt3DCore::QNodeCommand::<wbr/>setData(QVariant)</a></code></p>
     */
    @QtUninvokable
    public final void setData(java.lang.Object data){
        setData_native_cref_QVariant(QtJambi_LibraryUtilities.internal.nativeId(this), data);
    }
    
    @QtUninvokable
    private native void setData_native_cref_QVariant(long __this__nativeId, java.lang.Object data);
    
    /**
     * <p>See <code><a href="http://doc.qt.io/qt-5/qt3dcore-qnodecommand.html#setName">Qt3DCore::QNodeCommand::<wbr/>setName(QString)</a></code></p>
     */
    @QtUninvokable
    public final void setName(java.lang.@NonNull String name){
        setName_native_cref_QString(QtJambi_LibraryUtilities.internal.nativeId(this), name);
    }
    
    @QtUninvokable
    private native void setName_native_cref_QString(long __this__nativeId, java.lang.String name);
    
    /**
     * <p>See <code><a href="http://doc.qt.io/qt-5/qt3dcore-qnodecommand.html#setReplyToCommandId">Qt3DCore::QNodeCommand::<wbr/>setReplyToCommandId(Qt3DCore::QNodeCommand::CommandId)</a></code></p>
     */
    @QtUninvokable
    public final void setReplyToCommandId(long id){
        setReplyToCommandId_native_Qt3DCore_QNodeCommand_CommandId(QtJambi_LibraryUtilities.internal.nativeId(this), id);
    }
    
    @QtUninvokable
    private native void setReplyToCommandId_native_Qt3DCore_QNodeCommand_CommandId(long __this__nativeId, long id);
    
    /**
     * Constructor for internal use only.
     * @param p expected to be <code>null</code>.
     * @hidden
     */
    @NativeAccess
    protected QNodeCommand(QPrivateConstructor p) { super(p); } 
    
}
